@@ -30,7 +30,7 @@ CREATE TABLE server (
   version VARCHAR(16) NOT NULL
 ) ENGINE=InnoDB CHARSET=utf8;
 
-INSERT INTO server (version) VALUES ("1.0.32");
+INSERT INTO server (version) VALUES ("1.2.0");
 
 DROP TABLE IF EXISTS users;
 
@@ -69,6 +69,8 @@ CREATE TABLE users_private (
   addr_state VARCHAR(128) DEFAULT "",
   addr_country VARCHAR(64) DEFAULT "",
   phone VARCHAR(64) DEFAULT "",
+  gender CHAR DEFAULT '',
+  birthdate DATE,
   verified CHAR DEFAULT 'n',
   verified_time INT DEFAULT 0,
 
@@ -193,27 +195,69 @@ DROP TABLE IF EXISTS tourneys_schedule;
 CREATE TABLE tourneys_schedule (
   serial INT UNSIGNED NOT NULL AUTO_INCREMENT,
   name VARCHAR(32),
+  -- Description that will be shown in tournament lists
   description_short VARCHAR(64),
+  -- Description that will be shown on a detailed page about
+  -- the tournament.
   description_long TEXT,
+  -- The maximum number of players allowed to register in the tournament
   players_quota INT DEFAULT 10,
+  -- The minimum number of players to start the tournament. If the 
+  -- number of registered players in the tournament is less than this
+  -- limit, the tournament is canceled.
+  players_min INT DEFAULT 2,
+  -- Poker variant (holdem, omaha, omaha8, 7stud)
   variant VARCHAR(32),
+  -- Betting structure (.01-.02-no-limit, .01-.02-pot-limit, .02-.04-limit, .02-.04-no-limit, .02-.04-pot-limit, .02..04-limit, .05-.10-limit, .05-.10-no-limit, .05-.10-pot-limit, .05..10-limit, .10-.25-limit, .10-.25-no-limit, .10-.25-pot-limit, .25-.50-limit, .25-.50-no-limit, .25-.50-pot-limit, .25..50-limit, .50-1-limit, .50-1-no-limit, .50-1-pot-limit, .50.1-limit, 0-0-limit, 1-2-limit, 1-2-no-limit, 1-2-pot-limit, 10-15-limit, 10-15-pot-limit, 10-20-limit, 10-20-no-limit, 10-20-pot-limit, 100-200-limit, 100-200-no-limit, 100-200-pot-limit, 15-30-limit, 150-300-limit, 2-4-limit, 2-4-no-limit, 2-4-pot-limit, 200-400-limit, 3-6-limit, 3-6-no-limit, 3-6-pot-limit, 30-60-limit, 30-60-no-limit, 30-60-pot-limit, 4-8-limit, 5-10-limit, 5-10-no-limit, 5-10-pot-limit, 50-100-limit, 50-100-no-limit, 50-100-pot-limit)
   betting_structure VARCHAR(32),
+  -- Number of seats, in the range 2 and 10 included.
   seats_per_game INT DEFAULT 10,
+  -- Maximum number of seconds before a player times out when in position.
+  player_timeout INT DEFAULT 60,
+  -- Serial of the currency required to pay the buyin.
   currency_serial INT,
-  buy_in INT,
-  rake INT,
+  -- Minimum prize pool in cents.
+  prize_min INT DEFAULT 0,
+  -- Serial number of the player (serial field of the users table) 
+  -- who guarantees the minimum prize set in the prize_min field
+  -- if the total buyin payed by the players is not enough.
+  bailor_serial INT DEFAULT 0,
+  -- Tournament buyin in cent.
+  buy_in INT DEFAULT 0,
+  -- Tournament rake in cent.
+  rake INT DEFAULT 0,
+  -- y for sit&go tournament, n for regular tournament
   sit_n_go CHAR DEFAULT 'y',
-  breaks_interval INT DEFAULT 60,
+  -- Number of seconds for the first breaks.
+  breaks_first INT DEFAULT 7200,
+  -- Number of seconds between breaks after the first break.
+  breaks_interval INT DEFAULT 3600,
+  -- Number of seconds of each break.
+  breaks_duration INT DEFAULT 300,
+  -- Unused.
   rebuy_delay INT DEFAULT 0,
+  -- Unused.
   add_on INT DEFAULT 0,
+  -- Unused.
   add_on_delay INT DEFAULT 60,
+  -- Unix timestamp of the tournament start.
   start_time INT DEFAULT 0,
 
+  -- Unix timestamp of the registration start.
   register_time INT DEFAULT 0,
+  -- n : the tournament is ignored by the server, y : the tournament
+  -- is considered by the server.
+  active CHAR DEFAULT 'y',
+  -- y : the tournament restarts when complete, n : the tournament does
+  -- not restart when complete.
   respawn CHAR DEFAULT 'n',
+  -- Unused.
   respawn_interval INT DEFAULT 0,
 
-  PRIMARY KEY (serial)
+  PRIMARY KEY (serial),
+  KEY tourneys_schedule_active_index (active),
+  KEY tourneys_schedule_register_time_index (register_time)
+
 )  ENGINE=InnoDB CHARSET=utf8;
 
 --
@@ -293,12 +337,7 @@ VALUES ( 'Ositngo30', 'Sit and Go 3 tables, Omaha', 'Sit and Go 3 tables', '30',
 INSERT INTO `tourneys_schedule` ( `name`, `description_short` , `description_long` , `players_quota` , `variant` , `betting_structure` , `seats_per_game` , `currency_serial` , `buy_in` , `rake` , `sit_n_go` , `start_time` , `register_time` , `respawn` , `respawn_interval` )
 VALUES ( 'Ositngo50', 'Sit and Go 5 tables, Omaha', 'Sit and Go 5 tables', '50', 'omaha', 'level-15-30-no-limit', '10', 1, '300000', '0', 'y', '0', '0', 'y', '0' );
 
-INSERT INTO `tourneys_schedule` (`serial`, `name`, `description_short`, `description_long`, `players_quota`, `variant`, `betting_structure`, `seats_per_game`, `currency_serial`, `buy_in`, `rake`, `sit_n_go`, `breaks_interval`, `rebuy_delay`, `add_on`, `add_on_delay`, `start_time`, `register_time`, `respawn`, `respawn_interval`) VALUES ('', 'regular1', 'Holdem No Limit, 200 + 10', 'Holdem No Limit, 200 + 10', '1000', 'holdem', 'level-15-30-no-limit', '10', 1, '20000', '1000', 'n', '60', '30', '1', '60', unix_timestamp(now() + interval 8 hour), unix_timestamp(now() + interval 7 hour), 'n', '0');
-INSERT INTO `tourneys_schedule` (`serial`, `name`, `description_short`, `description_long`, `players_quota`, `variant`, `betting_structure`, `seats_per_game`, `currency_serial`, `buy_in`, `rake`, `sit_n_go`, `breaks_interval`, `rebuy_delay`, `add_on`, `add_on_delay`, `start_time`, `register_time`, `respawn`, `respawn_interval`) VALUES ('', 'regular2', 'Holdem No Limit, 2000 + 100', 'Holdem No Limit, 2000 + 100', '1000', 'holdem', 'level-15-30-no-limit', '10', 1, '200000', '10000', 'n', '60', '30', '1', '60', unix_timestamp(now() + interval 9 hour), unix_timestamp(now() + interval 8 hour), 'n', '0');
-INSERT INTO `tourneys_schedule` (`serial`, `name`, `description_short`, `description_long`, `players_quota`, `variant`, `betting_structure`, `seats_per_game`, `currency_serial`, `buy_in`, `rake`, `sit_n_go`, `breaks_interval`, `rebuy_delay`, `add_on`, `add_on_delay`, `start_time`, `register_time`, `respawn`, `respawn_interval`) VALUES ('', 'regular1', 'Omaha No Limit, 200 + 10', 'Omaha No Limit, 200 + 10', '1000', 'omaha', 'level-15-30-no-limit', '10', 1, '20000', '1000', 'n', '60', '30', '1', '60', unix_timestamp(now() + interval 10 hour), unix_timestamp(now() + interval 9 hour), 'n', '0');
-INSERT INTO `tourneys_schedule` (`serial`, `name`, `description_short`, `description_long`, `players_quota`, `variant`, `betting_structure`, `seats_per_game`, `currency_serial`, `buy_in`, `rake`, `sit_n_go`, `breaks_interval`, `rebuy_delay`, `add_on`, `add_on_delay`, `start_time`, `register_time`, `respawn`, `respawn_interval`) VALUES ('', 'regular2', 'Omaha No Limit, 2000 + 100', 'Omaha No Limit, 2000 + 100', '1000', 'omaha', 'level-15-30-no-limit', '10', 1, '200000', '10000', 'n', '60', '30', '1', '60', unix_timestamp(now() + interval 11 hour), unix_timestamp(now() + interval 10 hour), 'n', '0');
-INSERT INTO `tourneys_schedule` (`serial`, `name`, `description_short`, `description_long`, `players_quota`, `variant`, `betting_structure`, `seats_per_game`, `currency_serial`, `buy_in`, `rake`, `sit_n_go`, `breaks_interval`, `rebuy_delay`, `add_on`, `add_on_delay`, `start_time`, `register_time`, `respawn`, `respawn_interval`) VALUES ('', 'regular1', 'Omaha8 No Limit, 200 + 10', 'Omaha8 No Limit, 200 + 10', '1000', 'omaha8', 'level-15-30-no-limit', '10', 1, '20000', '1000', 'n', '60', '30', '1', '60', unix_timestamp(now() + interval 12 hour), unix_timestamp(now() + interval 11 hour), 'n', '0');
-INSERT INTO `tourneys_schedule` (`serial`, `name`, `description_short`, `description_long`, `players_quota`, `variant`, `betting_structure`, `seats_per_game`, `currency_serial`, `buy_in`, `rake`, `sit_n_go`, `breaks_interval`, `rebuy_delay`, `add_on`, `add_on_delay`, `start_time`, `register_time`, `respawn`, `respawn_interval`) VALUES ('', 'regular2', 'Omaha8 No Limit, 2000 + 100', 'Omaha8 No Limit, 2000 + 100', '1000', 'omaha8', 'level-15-30-no-limit', '10', 1, '200000', '10000', 'n', '60', '30', '1', '60', unix_timestamp(now() + interval 13 hour), unix_timestamp(now() + interval 12 hour), 'n', '0');
+INSERT INTO `tourneys_schedule` (`serial`, `name`, `description_short`, `description_long`, `players_quota`, `variant`, `betting_structure`, `seats_per_game`, `currency_serial`, `buy_in`, `rake`, `sit_n_go`, `breaks_interval`, `rebuy_delay`, `add_on`, `add_on_delay`, `start_time`, `register_time`, `respawn`, `respawn_interval`, `players_min`) VALUES ('', 'regular1', 'Holdem No Limit Freeroll', 'Holdem No Limit Freeroll', '1000', 'holdem', 'level-001', '10', 1, '0', '0', 'n', '60', '30', '1', '60', unix_timestamp(now() + INTERVAL 2 MINUTE), unix_timestamp(now()), 'y', '0', 3);
 
 DROP TABLE IF EXISTS tourneys;
 
@@ -308,14 +347,20 @@ CREATE TABLE tourneys (
   description_short VARCHAR(64),
   description_long TEXT,
   players_quota INT DEFAULT 10,
+  players_min INT DEFAULT 2,
   variant VARCHAR(32),
   betting_structure VARCHAR(32),
   seats_per_game INT DEFAULT 10,
+  player_timeout INT DEFAULT 60,
   currency_serial INT,
-  buy_in INT,
-  rake INT,
+  prize_min INT DEFAULT 0,
+  bailor_serial INT DEFAULT 0,
+  buy_in INT DEFAULT 0,
+  rake INT DEFAULT 0,
   sit_n_go CHAR DEFAULT 'y',
-  breaks_interval INT DEFAULT 60,
+  breaks_first INT DEFAULT 7200,
+  breaks_interval INT DEFAULT 3600,
+  breaks_duration INT DEFAULT 300,
   rebuy_delay INT DEFAULT 0,
   add_on INT DEFAULT 0,
   add_on_delay INT DEFAULT 60,
@@ -327,7 +372,9 @@ CREATE TABLE tourneys (
   add_on_count INT DEFAULT 0,
   rebuy_count INT DEFAULT 0,
 
-  PRIMARY KEY (serial)
+  PRIMARY KEY (serial),
+  KEY tourneys_start_time_index (start_time)
+
 )  ENGINE=InnoDB CHARSET=utf8;
 
 DROP TABLE IF EXISTS user2tourney;
@@ -366,7 +413,7 @@ CREATE TABLE users_transactions (
   notes TEXT,
 
   KEY (from_serial,to_serial)
-);
+) ENGINE=InnoDB CHARSET=utf8;
 
 DROP TABLE IF EXISTS affiliates;
 --
@@ -401,7 +448,7 @@ create table affiliates (
   notes TEXT,
 
   PRIMARY KEY (serial)
-);
+) ENGINE=InnoDB CHARSET=utf8;
 
 DROP TABLE IF EXISTS messages;
 
@@ -412,4 +459,4 @@ CREATE TABLE messages (
   sent CHAR DEFAULT 'n',
 
   PRIMARY KEY (serial, send_date, sent)
-)  ENGINE=InnoDB CHARSET=utf8;
+) ENGINE=InnoDB CHARSET=utf8;
