@@ -24,9 +24,14 @@
 #  Loic Dachary <loic@gnu.org>
 #
 from os.path import exists
+from traceback import print_exc
 
-import pygame
-
+try:
+    import pygame
+except:
+    print_exc()
+    print "pygame python module is missing, sound is disabled"
+    
 from twisted.internet import reactor
 
 from pokernetwork.pokerclientpackets import *
@@ -38,6 +43,10 @@ from pokerui.pokerdisplay import PokerDisplay
 import gtk
 import gtk.glade
 
+import gettext
+application = 'poker2d'
+gettext.install(application)
+
 class PokerPlayer2D:
     def __init__(self, player, table):
         self.table = table
@@ -93,9 +102,9 @@ class PokerPlayer2D:
                 self.cards[card_slot].hide()
             else:
                 if cards_numbers[card_index] == 255:
-                    self.cards[card_slot].set_from_file(glade.relative_file("pixmaps/cards/small-back.jpg"))
+                    self.cards[card_slot].set_from_file(glade.relative_file("cards/small-back.png"))
                 else:
-                    self.cards[card_slot].set_from_file(glade.relative_file("pixmaps/cards/small-%s.jpg" % cards_names[card_index]))
+                    self.cards[card_slot].set_from_file(glade.relative_file("cards/small-%s.png" % cards_names[card_index]))
                 self.cards[card_slot].show()
 
     def hideCards(self):
@@ -161,10 +170,11 @@ class PokerTable2D:
 
     def reset(self):
         self.serial2player = {}
-        fixed = self.glade.get_widget("game_fixed")
+        fixed = self.glade.get_widget("game_window_fixed")
         for widget in fixed.get_children():
             if widget.get_name() != "switch":
                 widget.hide()
+        self.glade.get_widget("game_background").show()
         if not self.game.isTournament():
             for seat in self.seats:
                 seat.show()
@@ -244,7 +254,7 @@ class PokerTable2D:
                 if i >= board_length:
                     self.board[i].hide()
                 else:
-                    self.board[i].set_from_file(self.glade.relative_file("pixmaps/cards/small-%s.jpg" % board[i]))
+                    self.board[i].set_from_file(self.glade.relative_file("cards/small-%s.png" % board[i]))
                     self.board[i].show()
 
         elif packet.type == PACKET_POKER_BET_LIMIT:
@@ -313,22 +323,33 @@ class PokerTable2D:
                     self.seats[packet.seat].show()
 
 class PokerDisplay2D(PokerDisplay):
+
     def __init__(self, *args, **kwargs):
         PokerDisplay.__init__(self, *args, **kwargs)
-        pygame.mixer.init()
+        if ( self.settings.headerGet("/settings/sound") == "yes" or
+             self.settings.headerGet("/settings/sound") == "on" ):
+            try:
+                pygame.mixer.init()
+                self.sound = True
+            except:
+                if self.settings.headerGetInt("/settings/@verbose") > 0:
+                    print_exc()
+                self.sound = False
+        else:
+            self.sound = False
         self.settings.notifyUpdates(self.settingsUpdated)
         self.settingsUpdated(self.settings)
         self.id2table = {}
 
     def __del__(self):
-        pygame.mixer.quit()
+        if self.sound:
+            pygame.mixer.quit()
 
     def settingsUpdated(self, settings):
         self.verbose = settings.headerGetInt("/settings/@verbose")
         self.datadir = settings.headerGet("/settings/data/@path")
         self.event2sound = None
-        if ( settings.headerGet("/settings/sound") == "yes" or
-             settings.headerGet("/settings/sound") == "on" ):
+        if self.sound:
             sounddir = settings.headerGet("/settings/data/@sounds")
             #
             # Load event to sound map
@@ -371,11 +392,15 @@ class PokerDisplay2D(PokerDisplay):
     def init(self):
         settings = self.settings
         config = self.config
-        gtkrc = self.datadir + "/interface/gtkrc"
+        gtkrc = self.datadir + "/interface/table/gtkrc"
         if exists(gtkrc):
             gtk.rc_parse(gtkrc)
-        glade_file = self.datadir + "/interface/interface2d.glade"
-        self.glade = gtk.glade.XML(fname = glade_file, root = "game_window")
+        glade_file = self.datadir + "/interface/table/mockup.glade"
+        glade = gtk.glade.XML(glade_file)
+        glade.signal_autoconnect(self)
+        from gamewindow import GameWindowGlade
+        self.glade = GameWindowGlade(glade)
+        self.glade.signal_autoconnect(self)
         self.actions = {
             "call": self.glade.get_widget("call"),
             "raise": self.glade.get_widget("raise"),
@@ -390,7 +415,6 @@ class PokerDisplay2D(PokerDisplay):
             "fold": self.glade.get_widget("fold"),
             }
         self.switch = self.glade.get_widget("switch")
-        self.glade.signal_autoconnect(self)
 #        self.actions['check'].add_accelerator("clicked", gtk.AccelGroup(), gtk.gdk.keyval_from_name("p"), gtk.gdk.MOD1_MASK, gtk.ACCEL_VISIBLE)
 
         self.animations = pokeranimation2d.create(self.glade, config, settings)
@@ -398,6 +422,26 @@ class PokerDisplay2D(PokerDisplay):
     def on_switch_clicked(self, button):
         self.renderer.rotateTable()
 
+    def on_sit_seat0_clicked(self, button):
+        self.on_sit_clicked(button)
+    def on_sit_seat1_clicked(self, button):
+        self.on_sit_clicked(button)
+    def on_sit_seat2_clicked(self, button):
+        self.on_sit_clicked(button)
+    def on_sit_seat3_clicked(self, button):
+        self.on_sit_clicked(button)
+    def on_sit_seat4_clicked(self, button):
+        self.on_sit_clicked(button)
+    def on_sit_seat5_clicked(self, button):
+        self.on_sit_clicked(button)
+    def on_sit_seat6_clicked(self, button):
+        self.on_sit_clicked(button)
+    def on_sit_seat7_clicked(self, button):
+        self.on_sit_clicked(button)
+    def on_sit_seat8_clicked(self, button):
+        self.on_sit_clicked(button)
+    def on_sit_seat9_clicked(self, button):
+        self.on_sit_clicked(button)
     def on_sit_clicked(self, button):
         seat = int(button.get_name()[-1])
         protocol = self.protocol
@@ -501,6 +545,7 @@ class PokerDisplay2D(PokerDisplay):
 
         if not packet.style:
             self.actions[packet.name].hide()
+            self.actions[packet.name].set_active(False)
             if packet.name == "raise":
                 self.actions["raise_range"].hide()
             return
