@@ -1,4 +1,5 @@
 #
+# Copyright (C) 2007 Loic Dachary <loic@dachary.org>
 # Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
@@ -21,13 +22,13 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.
 #
 # Authors:
-#  Cedric Pinson <cpinson@freesheep.org>
 #  Loic Dachary <loic@gnu.org>
 #  Johan Euphrosine <johan@mekensleep.com>
+#  Cedric Pinson <cpinson@freesheep.org> (2003-2006)
 #
 from pprint import pprint
-from twisted.internet import reactor
-from twisted.internet import defer
+from twisted.internet import reactor, defer
+from twisted.python.runtime import seconds
 
 from pokernetwork.pokerclientpackets import *
 from random import choice, uniform, randint
@@ -105,7 +106,7 @@ class PokerAnimationPlayer:
         self.timers = {}
 
     def endRound(self):
-        self.last_end_round=time()
+        self.last_end_round = seconds()
 
     def playerArrive(self):
         #print "player arrive run stand animation"
