@@ -45,6 +45,7 @@ if(!isset($GLOBALS['currency_db_user'])) $GLOBALS['currency_db_user'] = "currenc
 if(!isset($GLOBALS['currency_db_password'])) $GLOBALS['currency_db_password'] = "currency";
 
 if(!isset($GLOBALS['currency_random'])) $GLOBALS['currency_random'] = "/dev/urandom";
+if(!isset($GLOBALS['currency_id'])) $GLOBALS['currency_id'] = FALSE;
 
 if(!isset($GLOBALS['currency_url'])) {
   if(isset($_SERVER['SERVER_NAME'])) {
@@ -80,6 +81,9 @@ function rbccomp($a, $b) {
   return bccomp($b, $a);
 }
 
+$GLOBALS['currency_extension_loaded'] = 'extension_loaded';
+$GLOBALS['currency_dl'] = 'dl';
+
 class currency {
 
   const E_UNKNOWN		=	0;
@@ -103,9 +107,9 @@ class currency {
   var $fixedname = "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";
 
   function __construct($base = FALSE, $user = FALSE, $password = FALSE) {
-    if(!extension_loaded('mysql')) {
+    if(!$GLOBALS['currency_extension_loaded']('mysql')) {
       $prefix = (PHP_SHLIB_SUFFIX === 'dll') ? 'php_' : '';
-      if(!dl($prefix . 'mysql.' . PHP_SHLIB_SUFFIX)) {
+      if(!$GLOBALS['currency_dl']($prefix . 'mysql.' . PHP_SHLIB_SUFFIX)) {
         throw new Exception("unable to find or load mysql extension");
       }
     }
@@ -135,7 +139,9 @@ class currency {
 
   function __destruct() {
     if($this->db_connection != FALSE) mysql_close($this->connection);
-    fclose($this->random_fd);
+    $this->db_connection = FALSE;
+    if($this->random_fd) fclose($this->random_fd);
+    $this->random_fd = FALSE;
   }
 
   function transaction_wrap() {
@@ -180,20 +186,6 @@ class currency {
 
   function set_get_name($get_name) { $this->get_name = array(&$this, $get_name); }
 
-  function set_db_persist($persist) { $this->db_check_connection(); $this->db_persist = $persist; }
-
-  function set_db_prefix($prefix) { $this->db_check_connection(); $this->db_prefix = $prefix; }
-
-  function set_db_host($host) { $this->db_check_connection(); $this->db_host = $host; }
-
-  function set_db_port($port) { $this->db_check_connection(); $this->db_port = $port; }
-
-  function set_db_base($base) { $this->db_check_connection(); $this->db_base = $base; }
-
-  function set_db_user($user) { $this->db_check_connection(); $this->db_user = $user; }
-
-  function set_db_password($password) { $this->db_check_connection(); $this->db_password = $password; }
-
   function db_check_connection() {
     if($this->db_connection == FALSE) {
       $this->connection = call_user_func(($this->db_persist ? 'mysql_pconnect' : 'mysql_connect'),
@@ -206,16 +198,14 @@ class currency {
   function db_check_selected() {
     if($this->db_selected == FALSE) {
       $this->db_check_connection();
-      if(!mysql_query("CREATE DATABASE IF NOT EXISTS " . $this->db_base, $this->connection)) {
+      if(!mysql_query("CREATE DATABASE IF NOT EXISTS " . $this->db_base, $this->connection))
         throw new Exception("db_check_selected(1):" . mysql_error($this->connection));
-      }
-      if(!mysql_select_db($this->db_base, $this->connection)) {
-        throw new Exception("db_check_selected(2):" . mysql_error($this->connection));
-      }
+      if(!mysql_select_db($this->db_base, $this->connection)) throw new Exception("db_check_selected(2):" . mysql_error($this->connection)); // no coverage possible
 
-      $sql = "SHOW TABLES LIKE '" . $this->db_prefix . "_[0-9]%'";
+      $sql = "SHOW TABLES LIKE '" . $this->db_prefix . "_%'";
       $result = mysql_query($sql);
-      if(!$result) throw new Exception("db_check_selected(3):" . $sql . mysql_error($this->connection));
+      if(!$result)
+        throw new Exception("db_check_selected(3):" . $sql . mysql_error($this->connection));
       $count = mysql_num_rows($result);
       $this->value2table = array();
       $prefix = $this->db_prefix . "_";
@@ -223,9 +213,9 @@ class currency {
       if($count != FALSE && $count > 0) {
         while ($row = mysql_fetch_row($result)) {
           $table = $row[0];
-          if(strlen($table) <= $prefix_length) { // impossible because of the LIKE clause above 
-            throw new Exception("mysql table $table is shorter or equal than the expected prefix $prefix",  self::E_DATABASE_CORRUPTED);
-          }
+          if($table == $prefix . "transactions")
+            continue;
+          if(strlen($table) <= $prefix_length) throw new Exception("mysql table $table is shorter or equal than the expected prefix $prefix",  self::E_DATABASE_CORRUPTED); // impossible because of the LIKE clause above 
           $value = substr($table, $prefix_length);
           $this->value2table[$value] = $table;
         }
@@ -243,10 +233,11 @@ class currency {
         "   value BIGINT NOT NULL, " . 
         "   randname CHAR(40) NOT NULL UNIQUE, " .
         "   valid CHAR DEFAULT 'n' NOT NULL, " .
-        "   PRIMARY KEY (rowid, value, randname) " .
+        ($GLOBALS['currency_id'] ? "id INT NOT NULL, " : "") .
+        ($GLOBALS['currency_id'] ? "PRIMARY KEY (rowid, id, value, randname)  " : "PRIMARY KEY (rowid, value, randname)  " ) . 
         " ) ENGINE=InnoDB CHARSET=ascii;";
       if(!mysql_query($sql)) {
-        throw new Exception("db_check_selected(4):" . mysql_error($this->connection));
+        throw new Exception("db_check_selected(4): $sql: " . mysql_error($this->connection));
       }
 
       $sql = "CREATE TABLE IF NOT EXISTS " . $this->db_prefix . "_transactions ( " .
@@ -258,9 +249,7 @@ class currency {
         "   valid CHAR NOT NULL, " .
         "   INDEX ( transaction_id ) " .
         " ) ENGINE=InnoDB CHARSET=ascii;";
-      if(!mysql_query($sql)) {
-        throw new Exception("db_check_selected(4):" . mysql_error($this->connection));
-      }
+      if(!mysql_query($sql)) throw new Exception("db_check_selected(5):" . mysql_error($this->connection));
 
       $this->db_selected = TRUE;
     }
@@ -289,10 +278,11 @@ class currency {
         "   updated TIMESTAMP, " . 
         "   randname CHAR(40) NOT NULL UNIQUE, " .
         "   valid CHAR DEFAULT 'n' NOT NULL, " .
-        "   PRIMARY KEY (rowid, randname)  " . 
+        ($GLOBALS['currency_id'] ? "id INT NOT NULL, " : "") .
+        ($GLOBALS['currency_id'] ? "PRIMARY KEY (rowid, id, randname)  " : "PRIMARY KEY (rowid, randname)  " ) . 
         " ) ENGINE=InnoDB CHARSET=ascii;";
       if(!mysql_query($sql)) {
-        throw new Exception("db_check_or_create_table_value(1):" . mysql_error($this->connection));
+        throw new Exception("db_check_or_create_table_value(1): $sql: " . mysql_error($this->connection));
       }
       $this->value2table[$value] = TRUE;
     } elseif($value <= 0) {
@@ -326,17 +316,17 @@ class currency {
     return $result;
   }
 
-  function get_note($value) {
-    return $this->transaction_wrap('_get_note_transaction', $value);
+  function get_note($value, $id) {
+    return $this->transaction_wrap('_get_note_transaction', $value, $id);
   }
 
-  function _get_note_transaction($value) {
-    $note = $this->_get_note($value, 'n');
+  function _get_note_transaction($value, $id) {
+    $note = $this->_get_note($value, 'n', $id);
     $this->_transaction_add($note[2], 'n', $note);
     return $note;
   }
 
-  function _get_note($value, $valid) {
+  function _get_note($value, $valid, $id) {
     $done = FALSE;
     $this->db_check_or_create_table_value($value);
     $table = $this->value2table($value);
@@ -345,10 +335,18 @@ class currency {
     $randname = FALSE;
     while(!$done && $retry < 5) {
       $randname = call_user_func($this->get_name, $this);
-      if($is_private_table) {
-        $sql = "INSERT INTO ${table} (randname, valid) VALUES ('$randname', '$valid')";
+      if($GLOBALS['currency_id']) {
+        if($is_private_table) {
+          $sql = "INSERT INTO ${table} (randname, valid, id) VALUES ('$randname', '$valid', $id)";
+        } else {
+          $sql = "INSERT INTO ${table} (value, randname, valid, id) VALUES ($value, '$randname', '$valid', $id)";
+        }
       } else {
-        $sql = "INSERT INTO ${table} (value, randname, valid) VALUES ($value, '$randname', '$valid')";
+        if($is_private_table) {
+          $sql = "INSERT INTO ${table} (randname, valid) VALUES ('$randname', '$valid')";
+        } else {
+          $sql = "INSERT INTO ${table} (value, randname, valid) VALUES ($value, '$randname', '$valid')";
+        }
       }
       $status = $this->db_query($sql);
       if($status) {
@@ -416,7 +414,7 @@ class currency {
 
   function _commit($transaction_id, $sqls, $transactions_count) {
     //
-    // Run the SQL statements, verifying that each of them affect
+    // Run the SQL statements, verifying that each of them alter
     // the expected number of rows.
     //
     foreach ( $sqls as $sql ) {
@@ -461,27 +459,27 @@ class currency {
     }
   }
 
-  function check_note($serial, $name, $value) {
-    return $this->_check_note(array($this->url, $serial, $name, $value));
+  function check_note($serial, $name, $value, $id) {
+    return $this->_check_note(array($this->url, $serial, $name, $value), $id);
   }
 
-  function _check_note($note) {
+  function _check_note($note, $id) {
     list( $url, $serial, $name, $value ) = $note;
 
     $serial = intval($serial);
     $this->db_check_table_value($value);
     $table = $this->value2table($value);
-    $result = $this->db_query("SELECT rowid FROM ${table} WHERE rowid = $serial AND randname = '$name' AND valid = 'y'");
+    $result = $this->db_query("SELECT rowid FROM ${table} WHERE rowid = $serial AND randname = '$name' AND valid = 'y'" . ($GLOBALS['currency_id'] ? " AND id = $id" : ""));
     if(mysql_affected_rows($this->connection) != 1) {
       throw new Exception("failed to check note $serial $name" . mysql_error($this->connection), self::E_CHECK_NOTE_FAILED);
     }
     return $note;
   }
 
-  function change_note($serial, $name, $value) {
+  function change_note($serial, $name, $value, $id) {
     $serial = intval($serial);
-    $this->check_note($serial, $name, $value);
-    $note = $this->_get_note_transaction($value);
+    $this->check_note($serial, $name, $value, $id);
+    $note = $this->_get_note_transaction($value, $id);
     $this->_transaction_add($note[2], 'y', array($this->url, $serial, $name, $value));
     return $note;
   }
@@ -496,11 +494,11 @@ class currency {
     }
   }
 
-  function break_note($serial, $name, $value, $values = FALSE) {
-    return $this->transaction_wrap('_break_note', $serial, $name, $value, $values);
+  function break_note($serial, $name, $value, $id, $values = FALSE) {
+    return $this->transaction_wrap('_break_note', $serial, $name, $value, $id, $values);
   }
 
-  function _break_note($serial, $name, $value, $values) {
+  function _break_note($serial, $name, $value, $id, $values) {
     $serial = intval($serial);
     if($values == FALSE) {
       $values = $this->values;
@@ -514,16 +512,16 @@ class currency {
       $count = intval(bcdiv($value, $note_value)); 
       $value = bcmod($value, $note_value);
       for($i = 0; $i < $count; $i++)
-        array_push($notes, $this->_get_note($note_value, 'n'));
+        array_push($notes, $this->_get_note($note_value, 'n', $id));
       if(!(bccomp($value, 0) > 0)) break;
     }
 
     if(bccomp($value, 0) > 0) {
-      array_push($notes, $this->get_note($value));
+      array_push($notes, $this->get_note($value, $id));
     }
 
     $transaction_id = $notes[0][2];
-    $this->_check_note($to_delete);
+    $this->_check_note($to_delete, $id);
     $this->_transaction_add($transaction_id, 'y', $to_delete);
     foreach ( $notes as $note )
       $this->_transaction_add($transaction_id, 'n', $note);
@@ -534,7 +532,7 @@ class currency {
     return $notes;
   }
 
-  function merge_notes_columns($serials, $names, $values, $known_values = FALSE) {
+  function merge_notes_columns($serials, $names, $values, $id, $known_values = FALSE) {
     if(count($serials) != count($names) || count($names) != count($values)) {
       throw new Exception("serials, names and values must have the same size count(serials) = " . count($serials) . " count(names) = " . count($names) . " count(values) = " . count($values));
     }
@@ -542,16 +540,15 @@ class currency {
     // For the sake of genericity, merging a single note 
     // is equivalent to changing the note.
     //
-    if(count($serials) == 1) {
-      return array($this->change_note($serials[0], $names[0], $values[0]));
-    }
+    if(count($serials) == 1)
+      return array($this->change_note($serials[0], $names[0], $values[0], $id));
     $notes = array();
     for($i = 0; $i < count($serials); $i++)
       array_push($notes, array($this->url, intval($serials[$i]), $names[$i], $values[$i]));
-    return $this->merge_notes($notes, $known_values);
+    return $this->merge_notes($notes, $id, $known_values);
   }
 
-  function merge_notes($notes, $values = FALSE) {
+  function merge_notes($notes, $id, $values = FALSE) {
     if($values == FALSE) {
       $values = $this->values;
     } else {
@@ -575,10 +572,10 @@ class currency {
       throw new Exception("merge notes would not merge anything");
     }
 
-    return $this->transaction_wrap('_merge_notes', $value2count, $notes, $values);
+    return $this->transaction_wrap('_merge_notes', $value2count, $notes, $id, $values);
   }
 
-  function _merge_notes($value2count, $notes, $values) {
+  function _merge_notes($value2count, $notes, $id, $values) {
     $new_notes = array();
     $to_delete = array();
     if($values) {
@@ -594,7 +591,7 @@ class currency {
             unset($value2count[$value]);
           }
         } else {
-          $this->_check_note($note);
+          $this->_check_note($note, $id);
           array_push($to_delete, $note);
         }
       }
@@ -605,7 +602,7 @@ class currency {
     //
     foreach ( $value2count as $value => $count ) {
       for($i = 0; $i < $count; $i++)
-        array_push($new_notes, $this->_get_note(strval($value), 'n'));
+        array_push($new_notes, $this->_get_note(strval($value), 'n', $id));
     }
 
     $transaction_id = $new_notes[0][2];
@@ -624,7 +621,7 @@ class currency {
 //
 // Implement currency interaction if called from a standalone php script.
 //
-function currency_main($use_headers = True, $return_output = False) {
+function currency_main($use_headers = True, $return_output = FALSE) {
   ob_start();
   try {
     $page = array();
@@ -636,6 +633,12 @@ function currency_main($use_headers = True, $return_output = False) {
       $command = $_GET['command'];
     }
 
+    if(!isset($_GET['id'])) {
+      $id = 0;
+    } else {
+      $id = $_GET['id'];
+    }
+
     if($command == 'get_note') {
       if(isset($_GET['count'])) $count = $_GET['count'];
       else $count = 1;
@@ -643,9 +646,9 @@ function currency_main($use_headers = True, $return_output = False) {
       if(isset($_GET['autocommit'])) $autocommit = $_GET['autocommit'];
       for($i = 0; $i < $count; $i++) {
         if($autocommit == 'yes') {
-          $note = $currency->_get_note($_GET['value'], 'y');
+          $note = $currency->_get_note($_GET['value'], 'y', $id);
         } else {
-          $note = $currency->get_note($_GET['value']);
+          $note = $currency->get_note($_GET['value'], $id);
         }
         array_push($page, join("\t", $note));
       }
@@ -655,7 +658,7 @@ function currency_main($use_headers = True, $return_output = False) {
       } else {
         $_GET['values'] = FALSE;
       }
-      $notes = $currency->merge_notes_columns($_GET['serial'], $_GET['name'], $_GET['value'], $_GET['values']);
+      $notes = $currency->merge_notes_columns($_GET['serial'], $_GET['name'], $_GET['value'], $id, $_GET['values']);
       foreach ($notes as $note)
         array_push($page, join("\t", $note));
     } elseif($command == 'break_note') {
@@ -664,14 +667,14 @@ function currency_main($use_headers = True, $return_output = False) {
       } else {
         $_GET['values'] = FALSE;
       }
-      $notes = $currency->break_note($_GET['serial'], $_GET['name'], $_GET['value'], $_GET['values']);
+      $notes = $currency->break_note($_GET['serial'], $_GET['name'], $_GET['value'], $id, $_GET['values']);
       foreach ($notes as $note)
         array_push($page, join("\t", $note));
     } elseif($command == 'change_note') {
-      $note = $currency->change_note($_GET['serial'], $_GET['name'], $_GET['value']);
+      $note = $currency->change_note($_GET['serial'], $_GET['name'], $_GET['value'], $id);
       array_push($page, join("\t", $note));
     } elseif($command == 'check_note') {
-      $note = $currency->check_note($_GET['serial'], $_GET['name'], $_GET['value']);
+      $note = $currency->check_note($_GET['serial'], $_GET['name'], $_GET['value'], $id);
       array_push($page, join("\t", $note));
     } elseif($command == 'commit') {
       array_push($page, $currency->commit($_GET['transaction_id']));
@@ -686,7 +689,7 @@ function currency_main($use_headers = True, $return_output = False) {
     $status = true;
   } catch(Exception $error) {
     print $error->getMessage();
-    $status = false;
+    $status = FALSE;
   }
 
   if($use_headers) {
