@@ -23,7 +23,7 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.
 //
 // Authors:
-//  Morgan Manach <akshell@free.fr>
+//  Morgan Manach <akshell@free.fr> (2006)
 //  Loic Dachary <loic@gnu.org>
 //
 
@@ -62,23 +62,23 @@ if($poker_error) {
 		<table>
 			<tr>
 				<td></td>
-				<td>Login</td>
+				<td><? echo _('Login') ?></td>
 			</tr>
 			<tr>
-				<td><b>Login:</b></td>
+				<td><b><? echo _('Login') ?>:</b></td>
 				<td><input type="text" maxlength="32" name="login" value="<?php echo $name?>" /></td>
 			</tr>
 			<tr>
-				<td><b>Password:</b></td>
+				<td><b><? echo _('Password') ?>:</b></td>
 				<td><input type="password" maxlength="32" name="password" id="password" /></td>
 			</tr>
 			<tr>
 				<td></td>
-				<td><a href="create_account.php">Create account</a></td>
+				<td><a href="create_account.php"><? echo _('Create Account') ?></a></td>
 			</tr>
 			<tr>
 				<td></td>
-				<td><input type="submit" name='submit' value="Ok" /></td>
+				<td><input type="submit" name='submit' value="<? echo _('Ok') ?>" /></td>
 			</tr>
 		</table>
 	</form>
